#ifndef SETTINGSDLG_H
#define SETTINGSDLG_H

#include "settingswidget.h"
#include <QDialog>


namespace Ui {
    class settingsdlg;
}

class settingsdlg : public QDialog {
    Q_OBJECT
public:
    settingsdlg(QWidget *parent = 0);
    ~settingsdlg();

protected:
    void changeEvent(QEvent *e);


private:
    Ui::settingsdlg *ui;
    SettingsWidget *pw;





private slots:
    void on_pbSave_clicked();
    void on_pbCancel_clicked();
};

#endif // SETTINGSDLG_H
